@@ -11,8 +11,8 @@ class VulnerabilityManagementGateway(metaclass=ABCMeta):
         "send_vulnerability_management"
 
     @abstractmethod
-    def get_product_type_service(self, service, dict_args, secret_tool, config_tool):
-        "get_product_type_service"
+    def get_product_type_pipeline(self, pipeline, dict_args, secret_tool, config_tool):
+        "get_product_type_pipeline"
 
     @abstractmethod
     def get_findings_excepted(
