@@ -1,12 +1,20 @@
 from devsecops_engine_tools.engine_sca.engine_dependencies.src.domain.model.gateways.tool_gateway import (
     ToolGateway,
 )
+from devsecops_engine_tools.engine_sca.engine_dependencies.src.infrastructure.driven_adapters.dependency_check.dependency_check_deserialize import (
+    DependencyCheckDeserialize,
+)
+from devsecops_engine_tools.engine_sca.engine_dependencies.src.domain.model.ContextDependencies import (
+    ContextDependencies,
+)
 
 import requests
 import subprocess
 import os
 import platform
 import shutil
+from dataclasses import asdict
+import json
 
 from devsecops_engine_tools.engine_utilities.utils.utils import Utils
 from devsecops_engine_tools.engine_sca.engine_dependencies.src.infrastructure.helpers.get_artifacts import (
@@ -144,3 +152,44 @@ class DependencyCheckTool(ToolGateway):
         command_prefix = self.select_operative_system(cli_version)
         self.scan_dependencies(command_prefix, to_scan, token_engine_dependencies)
         return self.search_result()
+
+    def get_dependencies_context_from_results(self, path_file_results, remote_config):
+        deserializer = DependencyCheckDeserialize()
+        dependencies, namespace = deserializer.filter_vulnerabilities_by_confidence(path_file_results, remote_config)
+        context_dependencies_list = []
+
+        for dependency in dependencies:
+            vulnerabilities_node = dependency.find('ns:vulnerabilities', namespace)
+            if vulnerabilities_node:
+                vulnerabilities = vulnerabilities_node.findall('ns:vulnerability', namespace)
+                for vulnerability in vulnerabilities:
+                    data = deserializer.extract_common_vuln_data(vulnerability, dependency, namespace)
+                    references = deserializer.extract_references(vulnerability, namespace)
+
+                    context = ContextDependencies(
+                        cve_id=data["id"],
+                        severity=data["severity"],
+                        component=data["where"],
+                        package_name=data["where"].split(":")[0] if data["where"] else "",
+                        installed_version=data["where"].split(":")[2].lower() if len(data["where"].split(":")) == 3 else data["where"].split(":")[1].lower(),
+                        fixed_version=[data["fix"]] if data["fix"] else [],
+                        impact_paths=[],
+                        description=data["description"],
+                        references=references,
+                        source_tool="Dependency Check"
+                    )
+                    context_dependencies_list.append(context)
+
+        print("===== BEGIN CONTEXT OUTPUT =====")
+        print(
+            json.dumps(
+                {
+                    "dependencies_context": [
+                        asdict(context) for context in context_dependencies_list
+                    ]
+                },
+                indent=4,
+            )
+        )
+        print("===== END CONTEXT OUTPUT =====")
+        
\ No newline at end of file
